.pageblock h3{
	display: none;
}
.feedback{
	display: none;
}
.quiz-results{
	display: none;
}
.percentage.fail{
	color: #E03939;
	font-weight: bold;
}
.percentage.pass{
	color: #49B328;
	font-weight: bold;
}