{% load compress %}
{% compress css %}
    <link href="{{STATIC_URL}}quizblock_random/css/quizblock_random.css" rel="stylesheet">
{% endcompress %}


<div id="score">
	<p class="your-score">Your Score</p>
	<p class="percentage"></p>
</div>

<div id="feedback">
	<p class="feedback fail">Your score is lower than the score needed for a certificate of completion.
Based on your answers, you should go back and review the videos for the
sections on:</p>
	<p class="feedback weakness"></p>
<p class="feedback pass">Congrats your score meets the requirements needed for a certificate of completion.</p>
</div>


<script id="quizblock_randomjs" src="{{STATIC_URL}}quizblock_random/js/quizblock_random.js"></script>