{% load markup %}
<div class="answer-options">
  <ul type="A">
    {% for answer in question.answer_set.all %}

      {% if block.rhetorical %}
        <li><input name="question{{question.id}}" value="{{answer.label}}" type="radio" /> {{answer.label}}</li>
      {% else %}
        <li>
          {% if response %}
            
            {% ifequal response.value answer.value %}
              <div class="yours {% if answer.correct %}correct{% else %}incorrect{% endif %}">
                <input type="radio" checked> {{answer.label}}
              </div>
              <!--
                <span class="yours {% if response.is_correct %}correct{% else %}incorrect{% endif %}">{{answer.label}}</span>
              -->
            {% else %}
              <div class="{% if answer.correct %}correct{% else %}incorrect{% endif %}">
                <input type="radio" disabled> {{answer.label}}
              </div>
            {% endifequal %}

          {% else %}
            <input name="pageblock-{{block.pageblock.id}}-question{{question.id}}" value="{{answer.value}}" type="radio" /> {{answer.label}}
          {% endif %}
        </li>
      {% endif %}
    {% endfor %}
  </ul>
</div>
