{% load markup %}
{% load showscore %}
<ul class="quiz-results">
  {% get_questions section block question request.user as rq %}
  <li class="quiz-type">{{ block.quiz_type }}</li>
  <li class= "quiz-description">{{ block.description }}</li>
  <li class="is-correct {{ rq }}">{{ rq }}</li>
</ul>

