<div class="quizblock-random-wrapper">
{% load markup %}
{% load getresponse %}
{% if page_status == 'complete' %}
{% else %}
<div class="quizblock-description">
	{{ block.description|markdown }}
</div>
{% endif %}
{% load getquestionuserlock %}

{% if request.user.is_anonymous %}
  <p class="warning">You must be logged in to view this content</p>
{% else %}
	
	{% get_random_question section block request.user as rq %}
	{% for question in block.question_set.all %}
	  	{% if rq.id == question.id %}
			{% include 'quizblock_random/question.html' %}
		{% endif %}
	{% endfor %}

{% if block.rhetorical %}
  <script src="http://mt.ccnmtl.columbia.edu/pedialabs/js/quizshow.js" type="text/javascript" language="javascript"></script>
{% endif %}

{% endif %}
</div>